==> fireflutter-0.3.17.tar.gz: lib/src/text/texts.dart <==
class T {
  T._();

  /// Basic
  static const String yes = 'Yes';
  static const String no = 'No';
  static const String ok = 'OK';
  static const String save = 'Save';
  static const String cancel = 'Cancel';
  static const String error = 'Error';
  static const String name = 'Name';
  static const String inputName = 'Please enter your name.';
  static const String nameInputDescription = 'NameInputDescription';
  static const String saved = 'Saved.';
  static const String email = 'Email';
  static const String password = 'Password';
  static const String login = 'Login';
  static const String next = 'Next';
  static const String prev = 'Prev';
  static const String back = 'Back';
  static const String like = 'Like';
  static const String likes = 'Likes';
  static const String bookmark = 'Favorite';
  static const String bookmarked = 'Unfavorite';
  static const String bookmarkMessage = 'Favorite sucess';
  static const String bookmarkedMessage = 'Unfavorite success';

  /// Label, texts, buttons,
  static const String dismiss = 'dismiss';

  /// Chat
  ///
  static const String chat = 'Chat';
  static const String chatRoomNoMessageYet = 'There is no message, yet.';

  /// User
  static const String setting = 'Setting';
  static const String block = 'Block';
  static const String unblock = 'Unblock';
  static const String report = 'Report';
  static const String leave = 'Leave';
  static const String stateMessage = 'State Message';
  static const String stateMessageDescription = 'State Message Description';

  static const String blockConfirmTitle = 'Block this user?';
  static const String blockConfirmMessage =
      'Do you want to block this user?\nYou will not be able to contents of this user.';
  static const String unblockConfirmTitle = 'Unblock this user?';
  static const String unblockConfirmMessage =
      'You will be able to contents of this user.';
  static const String notVerifiedMessage = 'You have not verified yourself.';
  static const String writeYourMessage = 'Write your message';

  /// User and Profile
  static const String recentLoginRequiredForResign =
      'recentLoginRequiredForResign';

  static const String backgroundImage = 'Background Image';
  static const String profileUpdate = 'Profile Update';
  static const String profilePhoto = 'Profile Photo';
  static const String takePhotoClosely = 'Take a photo closely';

  static const String birthdateLabel = 'Birthdate';
  static const String birthdateSelectDescription = 'birthdateSelectDescription';
  static const String birthdateTapToSelect = 'Tap to select';
  static const String birthdate = 'birthdate';

  // profile update labels and error messages
  static const String gender = 'Gender';
  static const String male = 'Male';
  static const String female = 'Female';
  static const String nationality = 'Nationality';
  static const String region = 'Region';
  static const String pleaseInputBirthday = 'Please input your birthday';
  static const String pleaseSelectGender = 'Please select your gender';
  static const String addYourPhoto = 'Add your photo. (Minimum 2, Maximum 4)';
  static const String pleaseSelectNationality =
      'Please select your nationality';
  static const String pleaseSelectRegion = 'Please select your region';
  static const String pleaseInputOccupation = 'Please input your occupation';
  static const String pleaseAddMorePhotos =
      'Please add more photos (minimum 2 of photos and maximum 2 of photos)';
  static const String pleaseInputStateMessage =
      'Please input your state/introduction message';

  /// Forum Post Comment
  static const String deletePostConfirmTitle = 'Delete this post?';
  static const String deletePostConfirmMessage =
      'Are you sure you want to delete post?\nYou will not be able to recover this post.';

  static const String deleteCommentConfirmTitle = 'Delete this comment?';
  static const String deleteCommentConfirmMessage =
      'Are you sure you want to delete comment?';

  static const String occupation = 'occupation';
  static const String occupationInputDescription = 'occupationInputDescription';

  /// Block
  static const String blocked = 'Blocked';
  static const String blockedMessage = 'You have blocked this user.';
  static const String blockedTitleMessage = 'Blocked this user';
  static const String blockedContentMessage = 'You have blocked this user.';
  static const String blockedChatMessage = 'You have blocked this user.';
  // static const String blockedUserMessage = 'You have blocked this user.';

  static const String unblocked = 'Unblocked';
  static const String unblockedMessage = 'You have unblocked this user.';

  /// Report
  static const String reportInputTitle = 'Report';
  static const String reportInputMessage =
      'Please enter the reason for the report.';
  static const String reportInputHint = 'Reason';

  /// Phone sign in
  static const String phoneNumber = 'Phone Number';
  static const String phoneSignInHeaderTitle =
      'Please enter your phone number and tap "Get Verification Code" button.';
  static const String phoneNumberInputHint = 'Enter your phone number.';
  static const String phoneNumberInputDescription =
      'Input phone number. e.g 010 1234 5678 or 0917 1234 5678';

  static const String phoneSignInTimeoutTryAgain = 'Timeout. Please try again.';
  static const String phoneSignInGetVerificationCode = 'GetVerification Code';
  static const String phoneSignInInputSmsCode =
      'Input Verification Code and press submit button';
  static const String phoneSignInRetry = 'Retry';
  static const String phoneSignInVerifySmsCode = 'Verification Code';
}

==> fireflutter-0.3.19.tar.gz: lib/src/text/texts.dart <==
class T {
  T._();

  /// Basic
  static const String yes = 'Yes';
  static const String no = 'No';
  static const String ok = 'OK';
  static const String save = 'Save';
  static const String cancel = 'Cancel';
  static const String error = 'Error';
  static const String name = 'Name';
  static const String inputName = 'Please enter your name.';
  static const String nameInputDescription = 'NameInputDescription';
  static const String saved = 'Saved.';
  static const String email = 'Email';
  static const String password = 'Password';
  static const String login = 'Login';
  static const String next = 'Next';
  static const String prev = 'Prev';
  static const String back = 'Back';
  static const String like = 'Like';
  static const String likes = 'Likes';
  static const String bookmark = 'Favorite';
  static const String bookmarkMessage = 'Favorite sucess';
  static const String unbookmark = 'Unfavorite';
  static const String unbookmarkMessage = 'Unfavorite success';

  /// Label, texts, buttons,
  static const String dismiss = 'dismiss';

  /// Chat
  ///
  static const String chat = 'Chat';
  static const String chatRoomNoMessageYet = 'There is no message, yet.';

  /// User
  static const String setting = 'Setting';
  static const String block = 'Block';
  static const String unblock = 'Unblock';
  static const String report = 'Report';
  static const String leave = 'Leave';
  static const String stateMessage = 'State Message';
  static const String stateMessageDescription = 'State Message Description';

  static const String blockConfirmTitle = 'Block this user?';
  static const String blockConfirmMessage =
      'Do you want to block this user?\nYou will not be able to contents of this user.';
  static const String unblockConfirmTitle = 'Unblock this user?';
  static const String unblockConfirmMessage =
      'You will be able to contents of this user.';
  static const String notVerifiedMessage = 'You have not verified yourself.';
  static const String writeYourMessage = 'Write your message';
  static const String yourProfileWasVisited = 'Your profile was visited.';
  static const String visitYourProfile = 'visit your profile';

  /// User and Profile
  static const String recentLoginRequiredForResign =
      'recentLoginRequiredForResign';

  static const String backgroundImage = 'Background Image';
  static const String profileUpdate = 'Profile Update';
  static const String profilePhoto = 'Profile Photo';
  static const String takePhotoClosely = 'Take a photo closely';

  static const String birthdateLabel = 'Birthdate';
  static const String birthdateSelectDescription = 'birthdateSelectDescription';
  static const String birthdateTapToSelect = 'Tap to select';
  static const String birthdate = 'birthdate';

  // profile update labels and error messages
  static const String gender = 'Gender';
  static const String male = 'Male';
  static const String female = 'Female';
  static const String nationality = 'Nationality';
  static const String region = 'Region';
  static const String pleaseInputBirthday = 'Please input your birthday';
  static const String pleaseSelectGender = 'Please select your gender';
  static const String addYourPhoto = 'Add your photo. (Minimum 2, Maximum 4)';
  static const String pleaseSelectNationality =
      'Please select your nationality';
  static const String pleaseSelectRegion = 'Please select your region';
  static const String pleaseInputOccupation = 'Please input your occupation';
  static const String pleaseAddMorePhotos =
      'Please add more photos (minimum 2 of photos and maximum 2 of photos)';
  static const String pleaseInputStateMessage =
      'Please input your state/introduction message';

  /// Forum Post Comment
  static const String deletePostConfirmTitle = 'Delete this post?';
  static const String deletePostConfirmMessage =
      'Are you sure you want to delete post?\nYou will not be able to recover this post.';

  static const String deleteCommentConfirmTitle = 'Delete this comment?';
  static const String deleteCommentConfirmMessage =
      'Are you sure you want to delete comment?';

  static const String occupation = 'occupation';
  static const String occupationInputDescription = 'occupationInputDescription';

  /// Block
  static const String blocked = 'Blocked';
  static const String blockedMessage = 'You have blocked this user.';
  static const String blockedTitleMessage = 'Blocked this user';
  static const String blockedContentMessage = 'You have blocked this user.';
  static const String blockedChatMessage = 'You have blocked this user.';
  // static const String blockedUserMessage = 'You have blocked this user.';

  static const String unblocked = 'Unblocked';
  static const String unblockedMessage = 'You have unblocked this user.';

  /// Report
  static const String reportInputTitle = 'Report';
  static const String reportInputMessage =
      'Please enter the reason for the report.';
  static const String reportInputHint = 'Reason';

  /// Phone sign in
  static const String phoneNumber = 'Phone Number';
  static const String phoneSignInHeaderTitle =
      'Please enter your phone number and tap "Get Verification Code" button.';
  static const String phoneNumberInputHint = 'Enter your phone number.';
  static const String phoneNumberInputDescription =
      'Input phone number. e.g 010 1234 5678 or 0917 1234 5678';

  static const String phoneSignInTimeoutTryAgain = 'Timeout. Please try again.';
  static const String phoneSignInGetVerificationCode = 'GetVerification Code';
  static const String phoneSignInInputSmsCode =
      'Input Verification Code and press submit button';
  static const String phoneSignInRetry = 'Retry';
  static const String phoneSignInVerifySmsCode = 'Verification Code';
}
